[![Build Status](https://travis-ci.com/jugmac00/Products.ZopeTree.svg?branch=master)](https://travis-ci.com/jugmac00/Products.ZopeTree)
[![Current version on PyPI](https://img.shields.io/pypi/v/Products.ZopeTree)](https://pypi.org/project/Products.ZopeTree/)
[![License: MPL 1.1](https://img.shields.io/badge/License-MPL%201.1-brightgreen.svg)](https://opensource.org/licenses/MPL-2.0)

# Products.ZopeTree

ZopeTree is a light-weight tree implementation, mainly for use with ZPT.

Created by Philipp "philiKON" von Weitershausen.

## Scope

This package back from 2003 has been asleep for more than a decade.

It was about time to get up and get ready for Zope 4 and Python 3.
